@@ -1,18 +1,6 @@
-from typing import TypedDict
-
-from recharge.api import RechargeResource, RechargeScope, RechargeVersion
-
-
-class TokenClient(TypedDict):
-    name: str
-    email: str
-
-
-class TokenInformation(TypedDict):
-    client: TokenClient
-    contact_email: str
-    name: str
-    scopes: list[RechargeScope]
+from recharge.api import RechargeResource, RechargeVersion
+from recharge.exceptions import RechargeAPIError
+from recharge.model.v2.token import TokenInformation
 
 
 class TokenResource(RechargeResource):
@@ -21,6 +9,7 @@ class TokenResource(RechargeResource):
     """
 
     object_list_key = "token_information"
+    object_dict_key = "token_information"
     recharge_version: RechargeVersion = "2021-11"
 
     def get(self) -> TokenInformation:
@@ -28,4 +17,6 @@ class TokenResource(RechargeResource):
         https://developer.rechargepayments.com/2021-11/token_information/token_information_retrieve
         """
         data = self._http_get(self._url)
+        if not isinstance(data, dict):
+            raise RechargeAPIError(f"Expected dict, got {type(data).__name__}")
         return TokenInformation(**data)
